diff --git a/cooperative_cuisine/configs/environment_config.yaml b/cooperative_cuisine/configs/environment_config.yaml
index 8757937d591a48d24630e0f9f231a8448829bed4..d589789dcb43f573f2cc9fa212845b880399873c 100644
--- a/cooperative_cuisine/configs/environment_config.yaml
+++ b/cooperative_cuisine/configs/environment_config.yaml
@@ -55,8 +55,8 @@ layout_chars:
 
 
 orders:
-  order_gen_class: !!python/name:cooperative_cuisine.order.RandomOrderGeneration ''
-  # the class to that receives the kwargs. Should be a child class of OrderGeneration in order.py
+  order_gen_class: !!python/name:cooperative_cuisine.orders.RandomOrderGeneration ''
+  # the class to that receives the kwargs. Should be a child class of OrderGeneration in orders.py
   order_gen_kwargs:
     order_duration_random_func:
       # how long should the orders be alive
diff --git a/cooperative_cuisine/configs/study/level1/level1_config.yaml b/cooperative_cuisine/configs/study/level1/level1_config.yaml
index cb270a976ceff979008d975034fb789c77fd8f0b..d6e96cc48905873a9829e09535f1af071a1644ce 100644
--- a/cooperative_cuisine/configs/study/level1/level1_config.yaml
+++ b/cooperative_cuisine/configs/study/level1/level1_config.yaml
@@ -54,8 +54,8 @@ layout_chars:
 
 
 orders:
-  order_gen_class: !!python/name:cooperative_cuisine.order.RandomOrderGeneration ''
-  # the class to that receives the kwargs. Should be a child class of OrderGeneration in order.py
+  order_gen_class: !!python/name:cooperative_cuisine.orders.RandomOrderGeneration ''
+  # the class to that receives the kwargs. Should be a child class of OrderGeneration in orders.py
   order_gen_kwargs:
     order_duration_random_func:
       # how long should the orders be alive
diff --git a/cooperative_cuisine/configs/study/level2/level2_config.yaml b/cooperative_cuisine/configs/study/level2/level2_config.yaml
index a6759c7a60f2cfa49cab75a2372b54de4ee1c4a7..0473e208323c4eec8015829299a5c20c15784139 100644
--- a/cooperative_cuisine/configs/study/level2/level2_config.yaml
+++ b/cooperative_cuisine/configs/study/level2/level2_config.yaml
@@ -52,8 +52,8 @@ layout_chars:
 
 
 orders:
-  order_gen_class: !!python/name:cooperative_cuisine.order.RandomOrderGeneration ''
-  # the class to that receives the kwargs. Should be a child class of OrderGeneration in order.py
+  order_gen_class: !!python/name:cooperative_cuisine.orders.RandomOrderGeneration ''
+  # the class to that receives the kwargs. Should be a child class of OrderGeneration in orders.py
   order_gen_kwargs:
     order_duration_random_func:
       # how long should the orders be alive
diff --git a/cooperative_cuisine/configs/tutorial_env_config.yaml b/cooperative_cuisine/configs/tutorial_env_config.yaml
index 983b9a44163b3639eb764e66ac5349e64f3da4e7..1a41ba318239c52e435ae32ad9bdd34d34de6c6e 100644
--- a/cooperative_cuisine/configs/tutorial_env_config.yaml
+++ b/cooperative_cuisine/configs/tutorial_env_config.yaml
@@ -52,8 +52,8 @@ layout_chars:
 
 
 orders:
-  order_gen_class: !!python/name:cooperative_cuisine.order.RandomOrderGeneration ''
-  # the class to that receives the kwargs. Should be a child class of OrderGeneration in order.py
+  order_gen_class: !!python/name:cooperative_cuisine.orders.RandomOrderGeneration ''
+  # the class to that receives the kwargs. Should be a child class of OrderGeneration in orders.py
   order_gen_kwargs:
     order_duration_random_func:
       # how long should the orders be alive
diff --git a/cooperative_cuisine/counter_factory.py b/cooperative_cuisine/counter_factory.py
index f71ce4990f33d849f6437762a45cecbe517a75b0..2dc90d33f9ef70c837f042b1e991304f732bfe6a 100644
--- a/cooperative_cuisine/counter_factory.py
+++ b/cooperative_cuisine/counter_factory.py
@@ -60,7 +60,7 @@ from cooperative_cuisine.game_items import (
     Item,
 )
 from cooperative_cuisine.hooks import Hooks
-from cooperative_cuisine.order import OrderManager
+from cooperative_cuisine.orders import OrderManager
 from cooperative_cuisine.utils import get_closest
 
 T = TypeVar("T")
diff --git a/cooperative_cuisine/environment.py b/cooperative_cuisine/environment.py
index da6662784056181fb6e926394f4874c1e9280471..4242600930850af725c1e7f2824a2d40009fe48b 100644
--- a/cooperative_cuisine/environment.py
+++ b/cooperative_cuisine/environment.py
@@ -52,7 +52,7 @@ from cooperative_cuisine.hooks import (
     ITEM_INFO_CONFIG,
     POST_STEP,
 )
-from cooperative_cuisine.order import (
+from cooperative_cuisine.orders import (
     OrderManager,
     OrderConfig,
 )
diff --git a/cooperative_cuisine/reinforcement_learning/environment_config_rl.yaml b/cooperative_cuisine/reinforcement_learning/environment_config_rl.yaml
index 8dc06e5e9623cc39d3afe44ee5abca31eb58890d..5e75d9bdaea71f52507fa31d3fb1ed47b268bf84 100644
--- a/cooperative_cuisine/reinforcement_learning/environment_config_rl.yaml
+++ b/cooperative_cuisine/reinforcement_learning/environment_config_rl.yaml
@@ -56,7 +56,7 @@ layout_chars:
 
 orders:
   order_gen_class: !!python/name:cooperative_cuisine.order.RandomOrderGeneration ''
-  # the class to that receives the kwargs. Should be a child class of OrderGeneration in order.py
+  # the class to that receives the kwargs. Should be a child class of OrderGeneration in orders.py
   order_gen_kwargs:
     order_duration_random_func:
       # how long should the orders be alive
diff --git a/cooperative_cuisine/order.py b/cooperative_cuisine/orders.py
similarity index 98%
rename from cooperative_cuisine/order.py
rename to cooperative_cuisine/orders.py
index 7158df13f8ee92c5b5ef7feacda58702e2cf3780..460f457888663abe5c545e8476ee71d1788129b7 100644
--- a/cooperative_cuisine/order.py
+++ b/cooperative_cuisine/orders.py
@@ -6,7 +6,7 @@ It is very configurable by letting you reference own Python classes and function
 ```yaml
 orders:
   serving_not_ordered_meals: null
-  order_gen_class:  !!python/name:cooperative_cuisine.order.RandomOrderGeneration ''
+  order_gen_class:  !!python/name:cooperative_cuisine.orders.RandomOrderGeneration ''
   order_gen_kwargs:
     ...
 ```
@@ -97,7 +97,7 @@ class OrderGeneration:
     Example:
         ```yaml
         orders:
-          order_gen_class: !!python/name:cooperative_cuisine.order.RandomOrderGeneration ''
+          order_gen_class: !!python/name:cooperative_cuisine.orders.RandomOrderGeneration ''
           kwargs:
             ...
         ```
@@ -334,8 +334,8 @@ class RandomOrderGeneration(OrderGeneration):
     You can set this order generation in your `environment_config.yml` with
     ```yaml
     orders:
-      order_gen_class: !!python/name:cooperative_cuisine.order.RandomOrderGeneration ''
-      # the class to that receives the kwargs. Should be a child class of OrderGeneration in order.py
+      order_gen_class: !!python/name:cooperative_cuisine.orders.RandomOrderGeneration ''
+      # the class to that receives the kwargs. Should be a child class of OrderGeneration in orders.py
       order_gen_kwargs:
         order_duration_random_func:
           # how long should the orders be alive